@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013 - ntop.org
+ * (C) 2013-14 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,13 +33,14 @@ class ActivityStats {
   time_t begin_time, wrap_time, last_set_time, last_set_requested;
   void *_bitset;
   Mutex m;
-  
+
  public:
   ActivityStats(time_t when=0);
   ~ActivityStats();
 
   void reset();
   void set(time_t when);
+  void extractPoints(u_int8_t *elems);
   std::stringstream* getDump();
   void setDump(std::stringstream* dump);
   bool writeDump(char* path);
@@ -48,6 +49,8 @@ class ActivityStats {
   char* serialize();  
   void deserialize(json_object *o);
   inline time_t get_wrap_time() { return(wrap_time); };
+  /* Returns the Pearson correlation coefficient */
+  double pearsonCorrelation(ActivityStats *s);
 };
 
 #endif /* _ACTIVITY_STATS_H_ */
