@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013 - ntop.org
+ * (C) 2013-14 - ntop.org
  *
  *
  * This program is free software; you can addresstribute it and/or modify
@@ -24,11 +24,6 @@
 
 #include "ntop_includes.h"
 
-#define DEFAULT_CATEGORIZATION_KEY "9hoAtewwpC2tXRMJBfifrY24B"
-#define CATEGORIZATION_HOST        "service.block.si"
-#define CATEGORIZATION_URL         "/getRating"
-#define NULL_CATEGORY              "''"
-
 typedef struct {
   u_int8_t major, minor;
 } HostCategory;
@@ -41,6 +36,8 @@ class Categorization {
 
   void categorizeHostName(char *numeric_ip, char *buf, u_int buf_len);
 
+  static const int default_expire_time = 3600;
+
  public:
   Categorization(char *_api_key);
   ~Categorization();
