@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013 - ntop.org
+ * (C) 2013-14 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,27 +24,39 @@
 
 #include "ntop_includes.h"
 
-#ifdef HAVE_SQLITE
+typedef struct {
+  sqlite3 *db;
+  u_int32_t num_contacts_db_insert;
+  char last_open_contacts_db_path[MAX_PATH];
+  time_t last_insert;
+} db_cache;
 
 class DB {
  private:
+  u_int32_t contacts_cache_idx;
+  db_cache contacts_cache[CONST_NUM_OPEN_DB_CACHE];
   sqlite3 *db;
-
+  NetworkInterface *iface;
   u_int32_t dir_duration;
   char db_path[MAX_PATH];
   time_t end_dump;
+  u_int8_t db_id;
 
   void initDB(time_t when, const char *create_sql_string);
   void termDB();
-  bool execSQL(char* sql);
+  bool execSQL(sqlite3 *_db, char* sql);
+  int get_open_db_contacts_connection(char *path, int *db_to_purge);
 
  public:
-  DB(u_int32_t _dir_duration = 300 /* 5 minutes */);
+  DB(NetworkInterface *_iface = NULL,
+     u_int32_t _dir_duration = 300 /* 5 minutes */,
+     u_int8_t _db_id = 0);
   ~DB();
 
-  bool dumpFlow(time_t when, Flow *f);
+  inline u_int8_t get_db_id()       { return(db_id); };
+  bool dumpFlow(time_t when, Flow *f, char *json);
+  void dumpContacts(HostContacts *c, char *path);
+  bool execContactsSQLStatement(char* _sql);
 };
 
-#endif /* HAVE_SQLITE */
-
 #endif /* _DB_CLASS_H_ */
