@@ -1,12 +1,12 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
 
@@ -23,11 +23,13 @@ print("<tr><th>Copyright</th><td>"..info["copyright"].."</td></tr>\n")
 print("<tr><th>License</th><td><A HREF=http://www.gnu.org/licenses/gpl.html>"..info["license"].."</A>")
 
 print("<tr><th>Version</th><td>"..info["version"].."</td></tr>\n")
-print("<tr><th><i class=icon-user></i> Currently Logged User</th><td>".._SESSION["user"].."</td></tr>\n")
-print("<tr><th><i class=icon-time></i> Uptime</th><td>"..secondsToTime(info["uptime"]).."</td></tr>\n")
+print("<tr><th>Platform</th><td>"..info["platform"].."</td></tr>\n")
+print("<tr><th><i class='fa fa-user fa-lg'></i> Currently Logged User</th><td>".._SESSION["user"].."</td></tr>\n")
+print("<tr><th><i class='fa fa-time fa-lg'></i>Uptime</th><td>"..secondsToTime(info["uptime"]).."</td></tr>\n")
 print("<tr><th colspan=2 align=center>&nbsp;</th></tr>\n")
 print("<tr><th><a href=http://www.ntop.org/products/ndpi/>nDPI</A></th><td>".. info["version.ndpi"] .."</td></tr>\n")
-print("<tr><th><a href=http://twitter.github.io/><i class=icon-twitter></i> Twitter Bootstrap</A></th><td>2.3.1</td></tr>\n")
+print("<tr><th><a href=http://twitter.github.io/><i class=\'fa fa-twitter fa-lg'></i> Twitter Bootstrap</A></th><td>3.x</td></tr>\n")
+print("<tr><th><a href=http://fortawesome.github.io/Font-Awesome/><i class=\'fa fa-flag fa-lg'></i> Font Awesome</A></th><td>4.x</td></tr>\n")
 print("<tr><th><a href=http://www.rrdtool.org/>RRDtool</A></th><td>"..info["version.rrd"].."</td></tr>\n")
 print("<tr><th><a href=http://www.redis.io>Redis</A> Server</th><td>"..info["version.redis"].."</td></tr>\n")
 print("<tr><th><a href=https://github.com/valenok/mongoose>Mongoose web server</A></th><td>"..info["version.httpd"].."</td></tr>\n")
