@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,7 +7,7 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
 
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
@@ -19,13 +19,18 @@ print [[
      <style type="text/css">
      #map-canvas { width: 640px; height: 480px; }
    </style>
-
+<div class="container-fluid">
 <hr>
 <h2>Export Data</H2>
 <p>&nbsp;<p>
 
 <form class="form-horizontal" action="/lua/do_export_data.lua" method="GET">
+]]
 
+print('<input id="csrf" name="csrf" type="hidden" value="'..ntop.getRandomCSRFValue()..'" />\n')
+
+
+print [[
 
 <div class="control-group">
     <label class="control-label" for="hostIP">Host:</label>
@@ -36,25 +41,41 @@ print [[
     </div>
   </div>
 
+<div class="control-group">
+    <label class="control-label" for="hostVlan">Vlan:</label>
+    <div class="controls">
+      <input type="text" id="hostVlan" name="hostVlan" placeholder="Vlan">
 
+     <label><small>NOTE: If the field is empty vlan is set to 0.</small></label>
+    </div>
+  </div>
+</br>
 <div class="control-group">
 <div class="controls">
-<button type="submit" class="btn btn-primary">Export JSON Data</button> <button class="btn" type="reset">Reset Form</button>
+  <button type="submit" class="btn btn-primary">Export JSON Data</button> 
+  <button class="btn btn-default" type="reset">Reset Form</button>
 </div>
 </div>
 
 <script type='text/javascript'>
-	 $('#hostIP').typeahead({
-	     source: function (query, process) {
-	             return $.get('/lua/find_host.lua', { query: query }, function (data) {
-		                 return process(data.results);
-		});
-	 }
-	});
+  function auto_ip_mac () {
+   $('#hostIP').typeahead({
+       source: function (query, process) {
+               return $.get('/lua/find_host.lua', { query: query }, function (data) {
+                     return process(data.results);
+      });
+      }
+    });
+  }
+
+  $(document).ready(function(){
+    auto_ip_mac();
+  });
 </script>
 
 
 </form>
+</div>
 
 ]]
 
