@@ -1,17 +1,18 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
+require "graph_utils"
 
 hostname = _GET["name"]
 
 interface.find(ifname)
 host = interface.getAggregatedHostInfo(hostname)
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 --sendHTTPHeader('application/json')
 
 if(host == nil) then
@@ -19,7 +20,8 @@ if(host == nil) then
    return
 else
    diff = os.time()-host["seen.last"]
-   print('{ "name": \"' .. hostname .. '\", "last_seen": "' .. formatEpoch(host["seen.last"]) .. ' ['.. secondsToTime(diff) .. ' ago]", "num_contacts": ' .. host["pkts.rcvd"] .. ', "epoch": ' .. os.time())
+   print('{ "name": \"' .. hostname .. '\", "last_seen": "' .. formatEpoch(host["seen.last"]) .. ' ['.. secondsToTime(diff) .. ' ago]", "num_queries": ' .. host["queries.rcvd"] .. 
+   ', "traffic_volume": "' .. bytesToSize(host["bytes.sent"]+host["bytes.rcvd"]) .. '", "epoch": ' .. os.time())
 
 print(', "contacts": [')
 
