@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,11 +7,12 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
 interface.find(ifname)
 
-host = interface.getHostInfo(_GET["host"])
+host_info = url2hostinfo(_GET)
+host = interface.getHostInfo(host_info["host"],host_info["vlan"])
 
 if(host == nil) then
    print("\t[ ]\n")
@@ -23,7 +24,10 @@ else
    for id, _ in ipairs(l4_keys) do
       label = l4_keys[id][1]
       key = l4_keys[id][2]
-      traffic = host[key..".bytes.sent"] + host[key..".bytes.rcvd"]
+      traffic = 0		
+      if(host[key..".bytes.sent"] ~= nil) then traffic = traffic + host[key..".bytes.sent"] end
+      if(host[key..".bytes.recv"] ~= nil) then traffic = traffic + host[key..".bytes.recv"] end
+
       _ifstats[traffic] = label
       tot = tot + traffic
    end
@@ -34,7 +38,6 @@ else
    -- Print entries whose value >= 5% of the total
    threshold = (tot * 3) / 100
 
-
    print "[\n"
    num = 0
    accumulate = 0
