@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,18 +7,28 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
 interface.find(ifname)
 
 mode = _GET["mode"]
 type = _GET["type"]
-host = interface.getHostInfo(_GET["host"])
+host_info = url2hostinfo(_GET)
+host = interface.getHostInfo(host_info["host"],host_info["vlan"])
+
+
+if(host == nil) then
+   print("<div class=\"alert alert-danger\"><img src=/img/warning.png> This flow cannot be found (expired ?)</div>")
+else
 
 if((type == nil) or (type == "size")) then
+  
    if((mode == nil) or (mode == "sent")) then
+     
       what = host["pktStats.sent"]
+      
    else
+     
       what = host["pktStats.recv"]
    end
 end
@@ -52,3 +62,4 @@ end
 
 print "\n]"
 
+end
\ No newline at end of file
