@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -10,16 +10,17 @@ require "flow_utils"
 
 local json = require ("dkjson")
 
-host_ip = _GET["host"]
-if(host_ip ~= nil) then
+host_info = url2hostinfo(_GET)
+
+if(host_info["host"] ~= nil) then
    interface.find(ifname)
-   host = interface.getHostInfo(host_ip)
+   host = interface.getHostInfo(host_info["host"],host_info["vlan"]) 
 else
    host = "{}"
 end
 
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 --sendHTTPHeader('application/json')
 
 print(json.encode(host, { indent = true }))
