@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,7 +7,7 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
 
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
@@ -33,6 +33,7 @@ print [[
 <h2>Hosts GeoMap</H2>
 
     <script src="https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false"></script>
+    <script src="/js/markerclusterer.js"></script>
 <div class="container-fluid">
   <div class="row-fluid">
     <div class="span8">
@@ -56,7 +57,7 @@ var zoomIP = undefined;
 </html>
 ]]
 else 
-print("<div class=\"alert alert-error\"><img src=/img/warning.png> No results found</div>")
+print("<div class=\"alert alert-danger\"><img src=/img/warning.png> No results found</div>")
 end
 
 dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
\ No newline at end of file
