@@ -1,20 +1,17 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
+local debug = false
 
 sendHTTPHeaderLogout('text/html')
 
-ntop.deleteKey("sessions.".._SESSION["session"])
-ntop.deleteKey("sessions.".._SESSION["session"]..".ifname")
-
--- io.write("Deleting ".."sessions.".._SESSION["session"].."\n")
--- io.write("Deleting ".."sessions.".._SESSION["session"]..".ifname\n")
-
+ntop.delCache("sessions.".._SESSION["session"])
+if (debug) then io.write("Deleting ".."sessions.".._SESSION["session"].."\n") end
 
 print [[
  <meta http-equiv="refresh" content="1; URL=/">
