@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,12 +7,12 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/menu.inc")
 
-print('<div class="alert alert-error"><img src=/img/warning.png> Page not found</div>')
+print('<div class="alert alert-danger"><img src=/img/warning.png> Page not found</div>')
 
 print ("<center><H4>Unable to find URL <i>")
 
