@@ -1,5 +1,5 @@
 --
--- (C) 2013 - ntop.org
+-- (C) 2013-14 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,6 +7,6 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
 require "top_talkers"
 
-sendHTTPHeader('text/html')
+sendHTTPHeader('text/html; charset=iso-8859-1')
 
-print(getTopTalkers(ifname, _GET["mode"], _GET["epoch"]))
\ No newline at end of file
+print(getTopTalkers(getInterfaceId(ifname), ifname, _GET["mode"], _GET["epoch"]))
\ No newline at end of file
